@@ -16,8 +16,8 @@ test_that("default", {
   expect_is(tagkb, "shiny.tag")
   expect_length(htmltools::findDependencies(tagkb), 2)
   expect_identical(htmltools::findDependencies(tagkb)[[2]]$script, c("jquery.knob.min.js"))
-  expect_true(htmltools::tagHasAttribute(tagkb$children[[3]], "id"))
-  expect_identical(htmltools::tagGetAttribute(tagkb$children[[3]], "id"), "myKnob")
+  expect_true(htmltools::tagHasAttribute(tagkb$children[[length(tagkb$children)]], "id"))
+  expect_identical(htmltools::tagGetAttribute(tagkb$children[[length(tagkb$children)]], "id"), "myKnob")
 })
 
 
